==> kopete_4.13.0.orig.tar.xz: kopete-4.13.0/protocols/jabber/ui/dlgsearch.h <==

/***************************************************************************
                          dlgjabberbrowse.h  -  description
                             -------------------
    begin                : Wed Dec 11 2002
    copyright            : (C) 2002-2003 by Till Gerken <till@tantalo.net>
    email                : kopete-devel@kde.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGSEARCH_H
#define DLGSEARCH_H

#include "jabberaccount.h"
#include "jabberformtranslator.h"
#include "ui_dlgsearch.h"

class JabberXDataWidget;

class dlgSearch : public KDialog
{
	Q_OBJECT
public:
	dlgSearch(JabberAccount *account, const XMPP::Jid &jid, QWidget *parent = 0);
	~dlgSearch();

private slots:
	void slotGotForm();
	void slotSendForm();
	void slotSentForm();

private:
	Ui::dlgSearch ui;
	JabberAccount *mAccount;
	JabberXDataWidget *mXDataWidget;
	Form mForm;
	JabberFormTranslator * translator;
};

#endif

==> kopete-23.07.80.tar.xz: kopete-23.07.80/protocols/jabber/ui/dlgsearch.h <==

/***************************************************************************
                          dlgjabberbrowse.h  -  description
                             -------------------
    begin                : Wed Dec 11 2002
    copyright            : (C) 2002-2003 by Till Gerken <till@tantalo.net>
    email                : kopete-devel@kde.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGSEARCH_H
#define DLGSEARCH_H

#include <QDialog>

#include "jabberaccount.h"
#include "jabberformtranslator.h"
#include "ui_dlgsearch.h"

class QPushButton;
class QDialogButtonBox;

class JabberXDataWidget;

class dlgSearch : public QDialog
{
	Q_OBJECT
public:
	dlgSearch(JabberAccount *account, const XMPP::Jid &jid, QWidget *parent = nullptr);
	~dlgSearch();

private Q_SLOTS:
	void slotGotForm();
	void slotSendForm();
	void slotSentForm();

private:
	Ui::dlgSearch ui;
	JabberAccount *mAccount;
	JabberXDataWidget *mXDataWidget;
    QPushButton* mSearchButton;
    QDialogButtonBox* mButtonBox;
	Form mForm;
	JabberFormTranslator * translator;
};

#endif
